#!/usr/bin/env python3
# -*- coding: utf-8 -*-
# @Time:    2021-12-15 00:17
# @Author:  geng
# @Email:   yonglonggeng@163.com
# @WeChat:  superior_god
# @File:    Build.py
# @Project: BoxJellyfish
import pickle


class BJFTask(object):
    def __init__(self):
        # load_model_method
        f = open('resultStages/artifacts/model.pkl', 'rb')
        self.object_model = pickle.load(f)

    #     self.load_model(object_model)
    #
    def load_model(self):
        return self.object_model

    def predict(self, data, data2):
        return self.object_model.predict(data, data2)


def get_model():
    f = open('resultStages/artifacts/model.pkl', 'rb')
    return pickle.load(f)


def predict(object_model, data, data2):
    return object_model.predict(data, data2)


if __name__ == '__main__':
    model = get_model()
    predict(model, 1, 2)



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
# @Time:    2021-12-14 23:57
# @Author:  geng
# @Email:   yonglonggeng@163.com
# @WeChat:  superior_god
# @File:    utils.py
# @Project: BoxJellyfish
import os
import shutil


def bjf_copy_file(source_path, target_path):
    source_path = os.path.abspath(source_path)
    target_path = os.path.abspath(target_path)

    if not os.path.exists(target_path):
        os.makedirs(target_path)

    if os.path.exists(source_path):
        # root 所指的是当前正在遍历的这个文件夹的本身的地址
        # dirs 是一个 list，内容是该文件夹中所有的目录的名字(不包括子目录)
        # files 同样是 list, 内容是该文件夹中所有的文件(不包括子目录)
        for root, dirs, files in os.walk(source_path):
            for file in files:
                src_file = os.path.join(root, file)
                shutil.copy(src_file, target_path)
                print(src_file)

    print('copy files finished!')



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
# @Time:    2021-12-15 01:40
# @Author:  geng
# @Email:   yonglonggeng@163.com
# @WeChat:  superior_god
# @File:    web.py
# @Project: BoxJellyfish
import json
import os
import time

from flask import Flask, request
from resultStages.UserInterFace import *

os.environ['NLS_LANG'] = 'SIMPLIFIED CHINESE_CHINA.UTF8'

app = Flask(__name__)
userModel = UserModel()
userModel.load_model()


# =========================================
def event_api(data):
    with graph.as_default():
        set_session(sess)
        res = userModel.predict(data)
    return res


def is_tf():
    with open("resultStages/BJFConfig.json", 'r') as load_f:
        load_dict = json.load(load_f)

    return load_dict['framework']


# =========================================
@app.route('/invocations', methods=['POST'])
def event_extraction():
    data = request.get_json()
    if is_tf() == 'tf':
        res = event_api(data)
    else:
        res = userModel.predict(data)
    result = {
        "status": 0,
        "msg": "接口成功连接。" + time.strftime('%Y-%m-%d %H:%M:%S', time.localtime(time.time())),
        "data": res,
        "Info": "BDA-API"
    }

    return json.dumps(result, ensure_ascii=False, indent=4)


# if __name__ == "__main__":
app.run(host='0.0.0.0', port=8888)



#!/usr/bin/env python

from setuptools import setup, find_packages

# 第三方依赖
requires = [
    "flask"
]

# 导入静态文件
file_data = [
    ("bjf/static/", ["bjf/data.csv"]),
]

setup(
    name='BoxJellyfish',
    version='2.11',
    keywords=('deploy', 'egg', 'ai'),
    description='Automated deployment platform',
    license='MIT License',

    url='http://www.baidu.com',
    author='LongGengYong',
    author_email='yonglonggeng@163.com',

    packages=find_packages(),
    include_package_data=True,
    platforms='linux',
    install_requires=requires,
    zip_safe=False,
    data_files=file_data,
)




#!/usr/bin/env python3
# -*- coding: utf-8 -*-
# @Time:    2021-12-14 23:07
# @Author:  geng
# @Email:   yonglonggeng@163.com
# @WeChat:  superior_god
# @File:    __init__.py.py
# @Project: BoxJellyfish



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
# @Time:    2021-12-14 23:13
# @Author:  geng
# @Email:   yonglonggeng@163.com
# @WeChat:  superior_god
# @File:    BJFModel.py.py
# @Project: BoxJellyfish
import json
import os
import shutil
from distutils.core import setup

from Cython.Build import cythonize


class ModelAPI():
    def __init__(self):
        self.static_file = None
        self.model_file = None

    def load(self, static_file, model_file, pre, parameters, config=None):
        try:
            shutil.rmtree(pre + "Stages")
        except:
            print("remove over.")
        shutil.copytree(model_file, pre + "Stages/artifacts")
        shutil.copytree(static_file, pre + "Stages/static")

        # try:
        #     shutil.move(static_file, pre + "Stages/static")
        # except:
        #     print("static folder?")

        try:
            setup(ext_modules=cythonize(['UserInterFace.py']), script_args=["build_ext", "-b", pre + "Stages"])
            # shutil.copy("UserInterFace.py", pre + "Stages/")
        except:
            print("UserInterFace ?")
        self.pyfunc_path = os.path.abspath(pre + "Stages")
        if config != None:
            json.dump(config, open(self.pyfunc_path + '/BJFConfig.json', 'w'))

        target_path = pre + "Params"
        target_path = os.path.abspath(target_path)

        if not os.path.exists(target_path):
            os.makedirs(target_path)
        json.dump(parameters, open(target_path + '/parameters.json', 'w'))


class BJFModel(object):
    def __init__(self):
        pass

    def load_model(self):
        self.load_model = None

    def predict(self, data):
        pass
